summaryrefslogtreecommitdiffstats
path: root/kmail/kmlineeditspell.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/kmlineeditspell.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmlineeditspell.h')
-rw-r--r--kmail/kmlineeditspell.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/kmail/kmlineeditspell.h b/kmail/kmlineeditspell.h
index 46d4d0db..70c8316f 100644
--- a/kmail/kmlineeditspell.h
+++ b/kmail/kmlineeditspell.h
@@ -12,8 +12,9 @@ class TQPopupMenu;
class KMLineEdit : public KPIM::AddresseeLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMLineEdit(bool useCompletion, TQWidget *parent = 0,
+ KMLineEdit(bool useCompletion, TQWidget *tqparent = 0,
const char *name = 0);
signals:
@@ -21,7 +22,7 @@ signals:
void focusDown();
protected:
// Inherited. Always called by the parent when this widget is created.
virtual void loadContacts();
virtual void keyPressEvent(TQKeyEvent*);
@@ -40,8 +41,9 @@ private:
class KMLineEditSpell : public KMLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMLineEditSpell(bool useCompletion, TQWidget *parent = 0,
+ KMLineEditSpell(bool useCompletion, TQWidget *tqparent = 0,
const char *name = 0);
void highLightWord( unsigned int length, unsigned int pos );
void spellCheckDone( const TQString &s );
@@ -21,7 +22,7 @@ signals:
void focusDown();
protected:
- // Inherited. Always called by the parent when this widget is created.
+ // Inherited. Always called by the tqparent when this widget is created.
virtual void loadContacts();
virtual void keyPressEvent(TQKeyEvent*);